@@ -10,7 +10,7 @@ use Hash::Subset qw(hash_subset);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-09-27'; # DATE
 our $DIST = 'App-BrowserUtils'; # DIST
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 our %SPEC;
 
@@ -394,7 +394,7 @@ sub unpause_browsers {
 
 $SPEC{pause_and_unpause_browsers} = {
     v => 1.1,
-    summary => "Pause and unpause browsers periodically",
+    summary => "Pause and unpause browsers alternately",
     description => $desc_pause_and_unpause .
     "See also the separate `pause_browsers` and the `unpause_browsers` routines.\n\n",
     args => {
@@ -696,7 +696,7 @@ App::BrowserUtils - Utilities related to browsers, particularly modern GUI ones
 
 =head1 VERSION
 
-This document describes version 0.013 of App::BrowserUtils (from Perl distribution App-BrowserUtils), released on 2021-09-27.
+This document describes version 0.014 of App::BrowserUtils (from Perl distribution App-BrowserUtils), released on 2021-09-27.
 
 =head1 SYNOPSIS
 
@@ -776,7 +776,7 @@ Usage:
 
  pause_and_unpause_browsers(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
-Pause and unpause browsers periodically.
+Pause and unpause browsers alternately.
 
 A modern browser now runs complex web pages and applications. Despite browser's
 power management feature, these pages/tabs on the browser often still eat
